<?php

namespace Moamen\Business\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Moamen\Business\Models\Forms;

class FormsPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the forms.
     *
     * @param User $user
     * @param Forms $forms
     *
     * @return bool
     */
    public function view(User $user, Forms $forms)
    {
        if ($user->canDo('business.forms.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $forms->user_id;
    }

    /**
     * Determine if the given user can create a forms.
     *
     * @param User $user
     * @param Forms $forms
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('business.forms.create');
    }

    /**
     * Determine if the given user can update the given forms.
     *
     * @param User $user
     * @param Forms $forms
     *
     * @return bool
     */
    public function update(User $user, Forms $forms)
    {
        if ($user->canDo('business.forms.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $forms->user_id;
    }

    /**
     * Determine if the given user can delete the given forms.
     *
     * @param User $user
     * @param Forms $forms
     *
     * @return bool
     */
    public function delete(User $user, Forms $forms)
    {
        if ($user->canDo('business.forms.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $forms->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
